@@ -337,7 +337,7 @@ extern "C" {
         int *burn, int *reps, int *saveEvery, int *printEvery, int *t0, 
         double *lambdaA, double *lambdaB, double *ind, double *muA, double *gamma, //
         double *alphaA, double *alphaB, double *pi0, double *sigmaGamma,           // start parameters
-        double *psi0, double *tau )                                                //
+        double *psi0, double *tau, int *success )                                                //
     {
 
         state Q;
@@ -410,6 +410,10 @@ extern "C" {
                 Rprintf("++++++++++ Burn Step %6d ++++++++++\n", i + 1);
            
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
         }
 
@@ -421,6 +425,10 @@ extern "C" {
                 Rprintf("++++++++++ Repetition %5d ++++++++++\n", i + 1 );
 
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
             // save results //
 
@@ -484,7 +492,7 @@ extern "C" {
 
         }
         Rprintf("++++++++++++++++++++++++++++++++++++++\n");        
-
+        *success = 1;
     }
 
 
@@ -493,7 +501,7 @@ extern "C" {
         double *lambdaA, double *lambdaB, double *ind, double *muA, double *gamma, //
         double *alphaA, double *alphaB, double *pi0, double *sigmaGamma,           // start parameters
         double *psi0, double *tau,                                                 //
-        double *distGamma )                                                
+        double *distGamma, int *success )                                                
     {
         int ii, kk;
 
@@ -567,6 +575,10 @@ extern "C" {
                 Rprintf("++++++++++ Burn Step %6d ++++++++++\n", i + 1);
            
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
         }
 
@@ -579,6 +591,10 @@ extern "C" {
                 Rprintf("++++++++++ Repetition %5d ++++++++++\n", i + 1 );
 
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
             // save results //
 
@@ -651,6 +667,8 @@ extern "C" {
             }
         }
         Rprintf("++++++++++++++++++++++++++++++++++++++\n");        
+
+        *success = 1;
     }
 
     void rnaseq_verbose ( double *kA, double *kB, double *sA, double *sB, int *nA, int *nB, int *m,
@@ -658,7 +676,8 @@ extern "C" {
         double *lambdaA, double *lambdaB, double *ind, double *muA, double *gamma, //
         double *alphaA, double *alphaB, double *pi0, double *sigmaGamma,           // start parameters
         double *psi0, double *tau,                                                 //
-        double *distGamma, double *distMuA, double *distAlphaA, double *distAlphaB
+        double *distGamma, double *distMuA, double *distAlphaA, double *distAlphaB,
+        int *success
     )                  
     {
         int ii, kk;
@@ -733,6 +752,10 @@ extern "C" {
                 Rprintf("++++++++++ Burn Step %6d ++++++++++\n", i + 1);
            
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
         }
 
@@ -745,6 +768,10 @@ extern "C" {
                 Rprintf("++++++++++ Repetition %5d ++++++++++\n", i + 1 );
 
             updateState(Q);
+
+            if ( Q.sigmaGamma != Q.sigmaGamma )
+                return;
+
             R_CheckUserInterrupt();
             // save results //
 
@@ -821,6 +848,8 @@ extern "C" {
             }
         }
         Rprintf("++++++++++++++++++++++++++++++++++++++\n");        
+        *success = 1;
+
     }
 
 
